@@ -25,8 +25,9 @@ def load_pickled_list( local_root_directory= '../data/', list_pkl_file_name = 'm
         my_list = pickle.load(f)
     return my_list
 
-def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01'):
-    pickle_saving_path = local_root_directory+ssj+daily_return_pkl_filename_suffix
+def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
+    dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
+    pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+'_'+daily_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -98,6 +99,7 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         print('size fetched')
         print(dataframe.shape)
         dataframe = dataframe[dataframe.index >= daily_crypto_starting_day]
+        dataframe = dataframe[dataframe.index <= daily_crypto_ending_day]
         print('size filtered after '+str(daily_crypto_starting_day))
         print(dataframe.shape)
         dataframe.to_pickle(pickle_saving_path)
@@ -208,8 +210,9 @@ def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_ret
     return dataframe
 
 
-def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix=None,refetch_all=True, daily_crypto_starting_day='2012-01-01'):
-    pickle_saving_path = local_root_directory + ssj + hourly_return_pkl_filename_suffix
+def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix=None,refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None):
+    dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
+    pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + '_' + hourly_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
