@@ -15,7 +15,7 @@ from napoleontoolbox.parallel_run import launcher_utility
 import json
 import pandas as pd
 
-class RealTimeSignalEnsemblingParalleLauncher():
+class RealTimeBacktestSignalEnsemblingParalleLauncher():
     def __init__(self, starting_date=None, running_date=None, drop_token='', dropbox_backup=True, local_root_directory='../data',underlying = None, frequence='daily', selected_algo='',user='napoleon',  db_path_suffix = '_run.sqlite', list_pkl_file_suffix = 'my_list.pkl',freqly_return_pkl_filename_suffix='freqly_candels.pkl'):
         self.starting_date = starting_date
         self.running_date = running_date
@@ -57,13 +57,22 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.freqly_return_pkl_filename_suffix=freqly_return_pkl_filename_suffix
         self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_return_pkl_filename_suffix
-
-
-
-
+        freqly_df = pd.read_pickle(self.saving_return_path)
+        print('number of duplicated dates')
+        print(freqly_df.index.duplicated().sum())
+        freqly_df = freqly_df.sort_index()
+        print('time range before filtering ')
+        print(max(freqly_df.index))
+        print(min(freqly_df.index))
+        freqly_df = freqly_df[freqly_df.index >= self.starting_date]
+        freqly_df = freqly_df[freqly_df.index <= self.running_date]
+        print('time range after filtering ')
+        print(max(freqly_df.index))
+        print(min(freqly_df.index))
+        self.freqly_df = freqly_df
 
     def launchParallelPool(self, use_num_cpu):
-        print('launching parallel computation for alphas at '+str(self.last_minute))
+        print('launching parallel computation for alphas at ')
         with Pool(processes=use_num_cpu) as pool:
             run_results = pool.starmap(self.runTrial, self.args)
         print('parallel computation done')
@@ -72,7 +81,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
 
     def launchSequential(self):
-        print('launching sequential computation for alphas at '+str(self.last_minute))
+        print('launching sequential computation for alphas at ')
         run_results = []
         for meArg in self.args:
             run_results.append(self.runTrial(meArg))
