@@ -18,7 +18,8 @@ class AbstractRunner(ABC):
         self.freqly_pkl_file_name_suffix=freqly_pkl_file_name_suffix
         self.underlying = underlying
         self.local_root_directory=local_root_directory
-        self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_pkl_file_name_suffix
+        self.dates_stub = starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime('%d_%b_%Y')
+        self.saving_return_path = self.local_root_directory+self.underlying+ '_' + self.dates_stub + '_' + self.freqly_pkl_file_name_suffix
         self.user=user
         self.dropbox_backup = dropbox_backup
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
@@ -27,12 +28,12 @@ class AbstractRunner(ABC):
         self.period = period
 
     @abstractmethod
-    def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs):
+    def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator):
         pass
 
 class SimpleSignalRunner(AbstractRunner):
-    def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization):
-        saving_key, idios = saver.create_saving_key(seed, trigger, signal_type, idios_string, transaction_costs, normalization)
+    def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator):
+        saving_key, idios = saver.create_saving_key(seed, trigger, signal_type, idios_string, transaction_costs, normalization, modulator)
         check_run_existence, table_number = saver.checkRunExistence(saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(saving_key)
         assert check_run_existence == exhaustive_check_run_existence
@@ -71,7 +72,7 @@ class SimpleSignalRunner(AbstractRunner):
                 print('Trouble backtesting signal')
                 print(inst)
                 return
-
+        freqly_df['signal'] = freqly_df['signal']*modulator
 
         freqly_df, _ = signal_utility.reconstitute_signal_perf(data = freqly_df, transaction_cost = transaction_costs , normalization = normalization)
         sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period= self.period, from_ret=True)
