@@ -774,15 +774,15 @@ class RealTimeSignalEnsemblingParalleLauncher():
             new_data_sig = np.hstack((self.day_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
         else:
             new_data_sig = np.hstack((self.day_np.reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-        print('new daily data signal')
-        print(new_data_sig)
+        #print('new daily data signal')
+        #print(new_data_sig)
         if self.day_signal_np is None:
             self.day_signal_np = new_data_sig
         else:
             self.day_signal_np = np.vstack((self.day_signal_np, new_data_sig))
         if len(self.day_signal_np.shape)>1 and len(self.day_signal_np)>3:
-            print('last three daily signals')
-            print(self.day_signal_np[-3:])
+            #print('last three daily signals')
+            #print(self.day_signal_np[-3:])
             print('forward filling the triggered daily signals ')
             counter = 0
             for meArg in self.day_calib_signals_list:
@@ -817,25 +817,25 @@ class RealTimeSignalEnsemblingParalleLauncher():
             signal_value, trigger_value = self.runMinuteSignal(meArg)
             run_results.append(signal_value)
             trigger_results.append(trigger_value)
-        print('results length')
+        print('minute results length')
         print(len(run_results))
-        print('triggered results')
-        print(trigger_results)
+        #print('triggered results')
+        #print(trigger_results)
         new_data_sig = np.array(run_results)
         if len(self.minute_np.shape)>1:
             new_data_sig = np.hstack((self.minute_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
         else:
             new_data_sig = np.hstack((self.minute_np.reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-
-        print(new_data_sig)
+        #print('new minute signal')
+        #print(new_data_sig)
         if self.minute_signal_np is None:
             self.minute_signal_np = new_data_sig
         else:
             self.minute_signal_np = np.vstack((self.minute_signal_np, new_data_sig))
 
         if len(self.minute_signal_np.shape)>1 and len(self.minute_signal_np)>3:
-            print('last three signals')
-            print(self.minute_signal_np[-3:])
+            #print('last three signals')
+            #print(self.minute_signal_np[-3:])
             print('forward filling the triggered minute signals ')
             counter = 0
             for meArg in self.min_calib_signals_list:
